==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/JCObjectGenerator__24Dep.h <==
// class org.dellroad.jc.cgen.JCObjectGenerator$Dep

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 85ff750d23febde4 org_dellroad_jc_cgen_JCObjectGenerator__24Dep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_JCObjectGenerator__24Dep_H_
#define _JC_org_dellroad_jc_cgen_JCObjectGenerator__24Dep_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_refs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_nonrefs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$refs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$refs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$nonrefs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object;

typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vmethods	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtable	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *, struct _jc_java_lang_String$object *);
extern void _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method$_init$2f6520e6d1277a99(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *, struct _jc_java_lang_String$object *, jlong);

// Virtual methods
extern jboolean _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method$equals$8a15e0625571c581(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method$hashCode$53152098849316df(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vmethods	org_dellroad_jc_cgen_JCObjectGenerator__24Dep;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_refs {
	struct _jc_java_lang_String$object	*className;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$refs {
    _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_refs	org_dellroad_jc_cgen_JCObjectGenerator__24Dep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_nonrefs {
	jlong	hash;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_nonrefs	org_dellroad_jc_cgen_JCObjectGenerator__24Dep;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object {
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_JCObjectGenerator__24Dep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_JCObjectGenerator__24Dep_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/JCObjectGenerator__24Dep.h <==
// class org.dellroad.jc.cgen.JCObjectGenerator$Dep

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 85ff750d23febde4 org_dellroad_jc_cgen_JCObjectGenerator__24Dep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_JCObjectGenerator__24Dep_H_
#define _JC_org_dellroad_jc_cgen_JCObjectGenerator__24Dep_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_refs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_nonrefs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$refs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$refs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$nonrefs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object;

typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vmethods	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtable	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method$_init$2f6520e6d1277a99(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *, struct _jc_java_lang_String$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method$equals$8a15e0625571c581(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method$hashCode$53152098849316df(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vmethods	org_dellroad_jc_cgen_JCObjectGenerator__24Dep;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_refs {
	struct _jc_java_lang_String$object	*className;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$refs {
    _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_refs	org_dellroad_jc_cgen_JCObjectGenerator__24Dep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_nonrefs {
	jlong	hash;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$sub_nonrefs	org_dellroad_jc_cgen_JCObjectGenerator__24Dep;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$object {
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$vtype _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_JCObjectGenerator__24Dep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_JCObjectGenerator__24Dep$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_JCObjectGenerator__24Dep_H_ */
